@@ -1,25 +1,21 @@
-const
-    coap = require('../'),
-    async = require('async'),
-    Readable = require('stream').Readable,
-    requestNumber = 10
+const coap = require('../')
+const async = require('async')
+const Readable = require('stream').Readable
+const requestNumber = 10
 
-var targetServer,
-    proxy,
-    client1,
-    client2,
-    targetResults
+let targetServer
+let proxy
 
-function formatTitle(msg) {
+function formatTitle (msg) {
     return '\n\n' + msg + '\n-------------------------------------'
 }
 
-function requestHandler(req, res) {
+function requestHandler (req, res) {
     console.log('Target receives [%s] in port [8976] from port [%s]', req.payload, req.rsinfo.port)
     res.end('RES_' + req.payload)
 }
 
-function createTargetServer(callback) {
+function createTargetServer (callback) {
     console.log('Creating target server at port 8976')
 
     targetServer = coap.createServer(requestHandler)
@@ -27,12 +23,12 @@ function createTargetServer(callback) {
     targetServer.listen(8976, '0.0.0.0', callback)
 }
 
-function proxyHandler(req, res) {
+function proxyHandler (req, res) {
     console.log('Proxy handled [%s]', req.payload)
     res.end('RES_' + req.payload)
 }
 
-function createProxy(callback) {
+function createProxy (callback) {
     console.log('Creating proxy at port 6780')
 
     proxy = coap.createServer({ proxy: true }, proxyHandler)
@@ -40,23 +36,23 @@ function createProxy(callback) {
     proxy.listen(6780, '0.0.0.0', callback)
 }
 
-function sendRequest(proxied) {
-    return function(n, callback) {
-        var req = {
-                host: 'localhost',
-                port: 8976,
-                agent: false
-            },
-            rs = new Readable()
+function sendRequest (proxied) {
+    return (n, callback) => {
+        const req = {
+            host: 'localhost',
+            port: 8976,
+            agent: false
+        }
+        const rs = new Readable()
 
         if (proxied) {
             req.port = 6780
             req.proxyUri = 'coap://localhost:8976'
         }
 
-        request = coap.request(req)
+        const request = coap.request(req)
 
-        request.on('response', function(res) {
+        request.on('response', (res) => {
             console.log('Client receives [%s] in port [%s] from [%s]', res.payload, res.outSocket.port, res.rsinfo.port)
             callback()
         })
@@ -67,8 +63,8 @@ function sendRequest(proxied) {
     }
 }
 
-function executeTest(proxied) {
-    return function(callback) {
+function executeTest (proxied) {
+    return (callback) => {
         if (proxied) {
             console.log(formatTitle('Executing tests with proxy'))
         } else {
@@ -79,13 +75,13 @@ function executeTest(proxied) {
     }
 }
 
-function cleanUp(callback) {
-    targetServer.close(function () {
+function cleanUp (callback) {
+    targetServer.close(() => {
         proxy.close(callback)
     })
 }
 
-function checkResults(callback) {
+function checkResults (callback) {
     console.log(formatTitle('Finish'))
 }
 
@@ -95,4 +91,4 @@ async.series([
     executeTest(false),
     executeTest(true),
     cleanUp
-], checkResults)
\ No newline at end of file
+], checkResults)
